@@ -1,4 +1,4 @@
-VERSION = "1.0.6"
+VERSION = "1.0.7.1"
 # Get Phoenix files
 from . import build
 from ppm import PPM
@@ -52,14 +52,18 @@ def info_out(type='Info'):
     e = fore['reset']
   return f"[ {s}{type}{e} ]"
 
-if os.path.exists("Phoenix.config.json") and os.path.isfile("Phoenix.config.json"):
-  configfile = open("Phoenix.config.json")
+if os.path.exists("config.phoenix") and os.path.isfile("config.phoenix"):
+  configfile = open("config.phoenix")
   configcont = json.loads(configfile.read())
   configfile.close()
   for i in configcont.keys():
     config[i] = configcont[i]
 
-max_cpu_threads = len(os.sched_getaffinity(0))
+max_cpu_threads = os.cpu_count()
+if 'sched_getaffinity' in os.__dir__(): 
+  max_cpu_threads = len(os.sched_getaffinity(0))
+else:
+  print(f"{info_out('Info')} The host system does not support fetching the amount of usable cores")
 if config['verbose'] and config['threads'] < max_cpu_threads:
   print(f"{info_out('Info')} The server is running on {config['threads']} thread(s), while there are {max_cpu_threads} available.")
 
